/* Copyright (c) 2009 Ondrej Donek.
   See the file LICENSE.txt for licensing information. */

/**
 * Main controller object of link dialog
 * 
 * @type Object
 */
var tbLinkDialog = {
	
	get mStrbundle() { return document.getElementById("tbnotes-stringbundle"); },
	
	/**
	 * Holds object of edited link.
	 * 
	 * @type tbNotesLinkPrototype|NULL
	 */
	_editedLink: null,
	
	/**
	 * Fired when dialog is loading.
	 * 
	 * @return void
	 */
	onLoad: function() 
  {
		var op = "add";
		
		if(typeof(window.arguments[0].inn) != "undefined") {
		    if(window.arguments[0].inn != null) {
		        this._editedLink = window.arguments[0].inn;
		    }
		}
		
		this._updateUi();
	},
	
	/** 
	 * Updates dialog UI.
	 * 
	 * @return void
	 */
	_updateUi: function() 
    {
		var dlg = document.getElementById("tbnotes-link-dialog");
		var title = document.getElementById("tblinkdialog_title-textbox");
		var url = document.getElementById("tblinkdialog_url-textbox");
		
		if(this._editedLink != null) {
			// We are editing a link
			title.value = this._editedLink.mTitle;
			url.value = this._editedLink.mUrl;
			
			var title = dlg.getAttribute("titleEdit");
			if(typeof(this._editedLink.mId) != "undefined") {
				title = title + " #" + this._editedLink.mId;
			}
			
			dlg.setAttribute("title", title);
		} else {
			// We are adding a new link
			dlg.setAttribute("title", dlg.getAttribute("titleAdd"));
		}
		
		// Select title textbox
		title.focus();
	},
	
	/** 
	 * Fired when user accepted this dialog.
	 * 
	 * @return boolean
	 */
	onAccept: function() {
		try {
			var title = document.getElementById("tblinkdialog_title-textbox");
			var url = document.getElementById("tblinkdialog_url-textbox");
			
			// TODO Check if title is empty!
			// TODO Check if URL is empty!
			
			if(this._editedLink == null) {
				var noteObj = null;
				var winMan = Components.classes["@mozilla.org/appshell/window-mediator;1"].getService();
				var winManInt = winMan.QueryInterface(Components.interfaces.nsIWindowMediator);
				var win = winManInt.getMostRecentWindow("mail:3pane");
				
				with(win) {
					noteObj = new tbNotesLinkPrototype();
				}
				
				// We are adding a new link
				this._editedLink = noteObj;
				this._editedLink.mTitle = title.value;
				this._editedLink.mUrl = url.value;
			}
			else {
				// We are editing note
				this._editedLink.mTitle = title.value;
				this._editedLink.mUrl = url.value;
			}
	
			window.arguments[0].out = this._editedLink;
		} catch(e) { 
		    Components.utils.reportError(e); 
		}
		
		return true;
	}, 
	
	/**
	 * Fired when user canceled this dialog.
	 * 
	 * @return boolean
	 */
	onCancel: function()
	{
		var prefs = Components.classes["@mozilla.org/preferences-service;1"].
				getService(Components.interfaces.nsIPrefBranch);
		var pref = "extensions.tbnotes.dont_show_close_confirm";
		
		// Check if user want to see confirmation dialog
		if(prefs.prefHasUserValue(pref) === true) {
			if(prefs.getBoolPref(pref) === true) {
				return true;
			}
		}
		
		// Show confirmation if user really want to close unsaved note
		var prompts = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].
				getService(Components.interfaces.nsIPromptService);
		var title = tbLinkDialog.mStrbundle.getString("closeLinkDlgTitle");
		var desc = tbLinkDialog.mStrbundle.getString("closeLinkDlgDesc");
		var question = tbLinkDialog.mStrbundle.getString("doNotAskAgain");
		var check = { value: false };
		var res = prompts.confirmCheck(window, title, desc, question, check);
		
		prefs.setBoolPref(pref, check.value);
		
		return res;
	}
	
}; // End of tbLinkDialog
